@@ -2,6 +2,8 @@
 pub struct StreamMultiplexorConfig {
     pub max_frame_size: usize,
     pub buf_size: usize,
+    pub max_queued_frames: usize,
+    pub accept_queue_len: usize,
     pub identifier: &'static str,
 }
 
@@ -11,6 +13,8 @@ impl Default for StreamMultiplexorConfig {
         Self {
             max_frame_size: 4 * 1024 * 1024,
             buf_size: 1024 * 1024,
+            max_queued_frames: 256,
+            accept_queue_len: 16,
             identifier: "",
         }
     }
